@@ -19,8 +19,7 @@ import os
 import shutil
 import tempfile
 
-from yaml import dump
-from yaml import safe_load
+import yaml
 
 from ansible import constants
 from ansible import errors as ansible_errors
@@ -58,6 +57,14 @@ options:
     default: False
     required: False
     type: bool
+  yaml_width:
+    description:
+      - The maximum width of the YAML document. By default, Ansible uses the
+        PyYAML library which has a default 80 symbol string length limit.
+        To change the limit, the new value can be used here.
+    default: None
+    required: False
+    type: int
 author: Sean Mooney
 '''
 
@@ -71,6 +78,7 @@ Merge multiple yaml files:
         sources:
           - "/tmp/default.yml"
           - "/tmp/override.yml"
+        yaml_width: 131072
         dest:
           - "/tmp/out.yml"
 '''
@@ -83,7 +91,7 @@ class ActionModule(action.ActionBase):
     def read_config(self, source):
         result = None
         # Only use config if present
-        if os.access(source, os.R_OK):
+        if source and os.access(source, os.R_OK):
             with open(source, 'r') as f:
                 template_data = f.read()
 
@@ -96,7 +104,7 @@ class ActionModule(action.ActionBase):
             self._templar.environment.loader.searchpath = searchpath
 
             template_data = self._templar.template(template_data)
-            result = safe_load(template_data)
+            result = yaml.safe_load(template_data)
         return result or {}
 
     def run(self, tmp=None, task_vars=None):
@@ -116,6 +124,7 @@ class ActionModule(action.ActionBase):
         output = {}
         sources = self._task.args.get('sources', None)
         extend_lists = self._task.args.get('extend_lists', False)
+        yaml_width = self._task.args.get('yaml_width', None)
         if not isinstance(sources, list):
             sources = [sources]
         for source in sources:
@@ -130,11 +139,13 @@ class ActionModule(action.ActionBase):
         try:
             result_file = os.path.join(local_tempdir, 'source')
             with open(result_file, 'w') as f:
-                f.write(dump(output, default_flow_style=False))
+                f.write(yaml.dump(output, default_flow_style=False,
+                                  width=yaml_width))
 
             new_task = self._task.copy()
             new_task.args.pop('sources', None)
             new_task.args.pop('extend_lists', None)
+            new_task.args.pop('yaml_width', None)
             new_task.args.update(
                 dict(
                     src=result_file
@@ -149,7 +160,11 @@ class ActionModule(action.ActionBase):
                 loader=self._loader,
                 templar=self._templar,
                 shared_loader_obj=self._shared_loader_obj)
-            result.update(copy_action.run(task_vars=task_vars))
+            copy_result = copy_action.run(task_vars=task_vars)
+            copy_result['invocation']['module_args'].update({
+                'src': result_file, 'sources': sources,
+                'extend_lists': extend_lists})
+            result.update(copy_result)
         finally:
             shutil.rmtree(local_tempdir)
         return result
