@@ -48,6 +48,15 @@ function prepare_images {
         return
     fi
 
+    if [[ $BASE_DISTRO == "centos" ]] && [[ $BASE_DISTRO_MAJOR_VERSION -eq 9 ]]; then
+        sudo tee -a /etc/kolla/kolla-build.conf <<EOF
+
+[DEFAULT]
+base_tag = stream9
+EOF
+
+    fi
+
     if [[ $SCENARIO != "bifrost" ]]; then
         GATE_IMAGES="^cron,^fluentd,^glance,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^neutron,^nova-,^openvswitch,^rabbitmq,^horizon,^heat,^placement"
     else
@@ -93,8 +102,8 @@ function prepare_images {
         GATE_IMAGES="^cron,^fluentd,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
     fi
 
-    if [[ $SCENARIO == "prometheus-efk" ]]; then
-        GATE_IMAGES="^cron,^elasticsearch,^fluentd,^grafana,^haproxy,^keepalived,^kibana,^kolla-toolbox,^mariadb,^memcached,^prometheus,^rabbitmq"
+    if [[ $SCENARIO == "prometheus-opensearch" ]]; then
+        GATE_IMAGES="^cron,^fluentd,^grafana,^haproxy,^keepalived,^kolla-toolbox,^mariadb,^memcached,^opensearch,^prometheus,^rabbitmq"
     fi
 
     if [[ $SCENARIO == "monasca" ]]; then
